==> 2.0.12.tar.gz: lib/src/CheckoutPage.dart <==
//@dart=2.9
import 'package:flutter/material.dart';
import 'package:webview_flutter/webview_flutter.dart';
import 'ApiService.dart';


class CheckoutPage extends StatefulWidget {
  final String orderId;
  final String client_id;
  final String transactionId;
  final amount;
  final String merchandUserName;
  final String merchandPassword;
  final String sandbox;
  final String X_API_KEY;
  final String currency;
  final String accessToken;
  final Function actionAfterProccess;

  const CheckoutPage({Key key,
    @required this.orderId,
    @required this.client_id,
    @required this.transactionId,
    @required this.amount,
    @required this.merchandUserName,
    @required this.merchandPassword,
    @required this.sandbox,
    @required this.currency,
    @required this.accessToken,
    @required this.actionAfterProccess,
    @required this.X_API_KEY})
      : super(key: key);

  @override
  _CheckoutPageState createState() => _CheckoutPageState();
}

class _CheckoutPageState extends State<CheckoutPage> {
  WebViewController _webViewController;
  ApiService api = new ApiService();
  String get initialUrl => 'https://hostedpages.payunit.net/#/payunit-card?amount=${widget.amount}&t_id=${widget.transactionId}&order_id=${widget.orderId}&currency=${widget.currency}&client_id=${widget.client_id}&accessToken=${widget.accessToken}&isMobile=true';

  @override
  void initState() {
    // TODO: implement initState
    super.initState();
    api.closeDialog(context);
    print("This  is the Url paypal url $initialUrl");
  }


  @override
  Widget build(BuildContext context) {
    return Scaffold(
      resizeToAvoidBottomInset: false,
      body: SafeArea(
        child: WebView(
          initialUrl: initialUrl,
          javascriptMode: JavascriptMode.unrestricted,
          onWebViewCreated: (webViewController) =>
          _webViewController = webViewController,
          onPageFinished: (String url) {
            if (url == initialUrl) {
              print("onPageFished passed");
            }
          },
          navigationDelegate: (NavigationRequest request) {
            print("The request : $request");
            if (request.url.startsWith('https://success.com')) {
              // widget.actionAfterProccess(widget.transactionId,
              //     "SUCCESS");
              Navigator.of(context).pop();
            } else if (request.url.startsWith('https://cancel.com')) {
              // widget.actionAfterProccess(widget.transactionId,
              //     "FAILED");
              Navigator.of(context).pop();
            }
            return NavigationDecision.navigate;
          },
        ),
      ),
    );
  }
}

==> 3.0.6.tar.gz: lib/src/CheckoutPage.dart <==
import 'package:flutter/material.dart';
import 'package:webview_flutter/webview_flutter.dart';
import 'ApiService.dart';

class CheckoutPage extends StatefulWidget {
  final String orderId;
  final String client_id;
  final String transactionId;
  final amount;
  final String merchandUserName;
  final String merchandPassword;
  final String sandbox;
  final String X_API_KEY;
  final String currency;
  final String accessToken;
  final Function actionAfterProccess;

  const CheckoutPage({required Key? key,
    required this.orderId,
    required this.client_id,
    required this.transactionId,
    required this.amount,
    required this.merchandUserName,
    required this.merchandPassword,
    required this.sandbox,
    required this.currency,
    required this.accessToken,
    required this.actionAfterProccess,
    required this.X_API_KEY})
      : super(key: key);

  @override
  _CheckoutPageState createState() => _CheckoutPageState();
}

class _CheckoutPageState extends State<CheckoutPage> {
  late WebViewController _webViewController;
  ApiService api = new ApiService();
  String get initialUrl => 'https://hostedpages.payunit.net/#/payunit-card?amount=${widget.amount}&t_id=${widget.transactionId}&order_id=${widget.orderId}&currency=${widget.currency}&client_id=${widget.client_id}&accessToken=${widget.accessToken}&isMobile=true';

  @override
  void initState() {
    // TODO: implement initState
    super.initState();
    api.closeDialog(context);
    print("This  is the Url paypal url $initialUrl");
  }


  @override
  Widget build(BuildContext context) {
    return Scaffold(
      resizeToAvoidBottomInset: false,
      body: SafeArea(
        child: WebView(
          initialUrl: initialUrl,
          javascriptMode: JavascriptMode.unrestricted,
          onWebViewCreated: (webViewController) =>
          _webViewController = webViewController,
          onPageFinished: (String url) {
            if (url == initialUrl) {
              print("onPageFished passed");
            }
          },
          navigationDelegate: (NavigationRequest request) {
            print("The request : $request");
            if (request.url.startsWith('https://success.com')) {
              // widget.actionAfterProccess(widget.transactionId,
              //     "SUCCESS");
              Navigator.of(context).pop();
            } else if (request.url.startsWith('https://cancel.com')) {
              // widget.actionAfterProccess(widget.transactionId,
              //     "FAILED");
              Navigator.of(context).pop();
            }
            return NavigationDecision.navigate;
          },
        ),
      ),
    );
  }
}
